-------------------------------------------------------------------------------
-- ESSHWL tables
--
-- This is the database setup script for the ESSHWL schema.
-------------------------------------------------------------------------------

------ Change Log -------------------------------------------------------------
--  Flag  Track   Staff            Date        Description
-- ------ -----  -------------  ----------  -----------------------------------
--  none         Todd Schlomer  2005/04/01   Initial Creation
--  none  23232  Todd Schlomer  2006/07/06   Add indexes to tables
--  none  23325  Jay Calder		2006/07/14	 Removed extra index parameters
--  none  23341  Todd Schlomer  2006/07/17   Added site location support
-------------------------------------------------------------------------------

CREATE SCHEMA ESSHWL;

-- ESSHWL.ESSSERVERMAPPING
DROP TABLE ESSHWL.ESSSERVERMAPPING;
CREATE TABLE ESSHWL.ESSSERVERMAPPING
  (ESSNAME VARCHAR(250) NOT NULL,
   SERVERLOCATION VARCHAR(250) NOT NULL,
   ESSINFORMATION BLOB(1K) NOT NULL);

ALTER TABLE ESSHWL.ESSSERVERMAPPING
  ADD CONSTRAINT PK_ESSSERVERMAPPIN PRIMARY KEY (SERVERLOCATION, ESSNAME);

CREATE INDEX ESSHWL.ESSSMIDX ON ESSHWL.ESSSERVERMAPPING 
	(ESSNAME ASC, SERVERLOCATION ASC);

-- ESSHWL.SERVERLOCATIONMAPPING
DROP TABLE ESSHWL.SERVERLOCATIONMAPPING;
CREATE TABLE ESSHWL.SERVERLOCATIONMAPPING
  (SERVERLOCATION VARCHAR(250) NOT NULL,
   USERNAME VARCHAR(250),
   PASSWORD VARCHAR(250),
   UNIQUENAME VARCHAR(250),
   NOTIFICATIONPORT INTEGER NOT NULL,
   SERVERTYPE SMALLINT NOT NULL,
   HOSTNAMECLUSTER0 VARCHAR(250),
   PORTNUMBERCLUSTER0 INTEGER NOT NULL,
   USERNAMECLUSTER0 VARCHAR(250),
   PASSWORDCLUSTER0 VARCHAR(250),
   HOSTNAMECLUSTER1 VARCHAR(250),
   PORTNUMBERCLUSTER1 INTEGER NOT NULL,
   USERNAMECLUSTER1 VARCHAR(250),
   PASSWORDCLUSTER1 VARCHAR(250),
   SITELOCATIONID SMALLINT NOT NULL DEFAULT 0);

ALTER TABLE ESSHWL.SERVERLOCATIONMAPPING
  ADD CONSTRAINT PK_SERVERLOCATION PRIMARY KEY (SERVERLOCATION);

CREATE INDEX ESSHWL.SERVLIDX ON ESSHWL.SERVERLOCATIONMAPPING 
	(SERVERLOCATION ASC, HOSTNAMECLUSTER0 ASC, HOSTNAMECLUSTER1 ASC, SERVERTYPE ASC);

-- ESSHWL.ESSPATH
DROP TABLE ESSHWL.ESSPATH;
CREATE TABLE ESSHWL.ESSPATH
  (PATHID VARCHAR(250) NOT NULL,
   PATHTYPE SMALLINT NOT NULL,
   SERVERLOCATION VARCHAR(250) NOT NULL,
   PATHSTATE SMALLINT NOT NULL,
   SOURCEPORTS BLOB(1K) NOT NULL,
   TARGETPORTS BLOB(1K) NOT NULL,
   AUTOGENERATED BLOB(1K) NOT NULL,
   SOURCEWWNN VARCHAR(250) NOT NULL,
   TARGETWWNN VARCHAR(250) NOT NULL);

ALTER TABLE ESSHWL.ESSPATH
  ADD CONSTRAINT PK_ESSPATH PRIMARY KEY (PATHTYPE, PATHID, SERVERLOCATION);

CREATE INDEX ESSHWL.EPATHIDX ON ESSHWL.ESSPATH 
	(PATHID ASC, PATHTYPE ASC, SERVERLOCATION ASC);

-- ESSHWL.ASYNCMASTERQUERYMONITOR
DROP TABLE ESSHWL.ASYNCMASTERQUERYMONITOR;
CREATE TABLE ESSHWL.ASYNCMASTERQUERYMONITOR
  (ESSNAME VARCHAR(250) NOT NULL,
   SESSIONNUMBER INTEGER NOT NULL,
   LSSNUMBER INTEGER NOT NULL,
   SSID INTEGER NOT NULL,
   QUERYISRUNNING SMALLINT NOT NULL);

ALTER TABLE ESSHWL.ASYNCMASTERQUERYMONITOR
  ADD CONSTRAINT PK_ASYNCMASTERQUER PRIMARY KEY (ESSNAME, SESSIONNUMBER, LSSNUMBER);

CREATE INDEX ESSHWL.ASCMQIDX ON ESSHWL.ASYNCMASTERQUERYMONITOR 
	(ESSNAME ASC, SESSIONNUMBER ASC, QUERYISRUNNING ASC);